local character
local outline

local ruby1
local ruby2

local spotlight
local cx, cy, scx, scy, ccx, ccy

local vel = 180
local min, max = -300, 300
local x = min
local x2 = min +320
local shader

local scale = 1

function love.load()
	love.graphics.setDefaultFilter("nearest", "nearest") --disable blurry scaling
	overlay = love.graphics.newImage('curtain.png')

  cx, cy = love.graphics.getWidth()/2, love.graphics.getHeight()/2
  character = love.graphics.newImage('Character.png')
  outline = love.graphics.newImage('CharacterOutline.png')

  ruby1 = love.graphics.newImage('sprite_ruby1.png')
  ruby2 = love.graphics.newImage('sprite_ruby2.png')

  spotlight = love.graphics.newImage('Spotlight.png')
  scx, scy = spotlight:getWidth()/2, spotlight:getHeight()/2
  -- outline:getDimensions() assumed to be equal to character:getDimensions()
  ccx, ccy = character:getWidth()/2, character:getHeight()/2

  shader = love.graphics.newShader[[
    vec4 effect(vec4 colour, Image texture, vec2 texpos, vec2 scrpos)
    {
      vec4 pixel = Texel(texture, texpos) * colour;
      if (pixel.a < 0.5) discard;
      return pixel;
    }
  ]]
end


function love.update(dt)
	get_input()

  x = x + vel * dt
  if x > max then x = x - (max - min) end

  x2 = x2 + vel * dt
  if x2 > max then x2 = x2 - (max - min) end

end



local function stencilFunction()
  love.graphics.setShader(shader)
  love.graphics.draw(spotlight, cx, cy, 0, 1, 1, scx, scy)
  love.graphics.setShader()
end


function love.draw()
	love.graphics.push()
	love.graphics.scale(scale, scale)

  love.graphics.stencil(stencilFunction)
  love.graphics.translate(cx, cy)
  love.graphics.draw(spotlight, 0,0,  0,  1,1,  scx,scy)

  love.graphics.setStencilTest("equal", 1)
  love.graphics.draw(character, x,0,  0,  1,1,  ccx,ccy)
  love.graphics.setStencilTest("notequal", 1)
  love.graphics.draw(outline,   x,0,  0,  1,1,  ccx,ccy)
  love.graphics.setStencilTest("always", 0)

  love.graphics.setStencilTest("equal", 1)
  love.graphics.draw(ruby1, x2,0,  0,  1,1,  ccx,ccy)
  love.graphics.setStencilTest("notequal", 1)
  love.graphics.draw(ruby2, x2,0,  0,  1,1,  ccx,ccy)
  love.graphics.setStencilTest("always", 0)

	love.graphics.draw(overlay, -320, -240)

	love.graphics.pop()
end

function love.keypressed(k) return k == "escape" and love.event.quit() end











function get_input()
	if love.keyboard.isDown("1") then
		if scale ~= 1 then
			scale = 1
			love.window.setMode(640, 480)
		end
	end

	if love.keyboard.isDown("2") then
		if scale ~= 2 then
			scale = 2
			love.window.setMode(1280, 960)
		end
	end
end







